# question-cache [![NPM version](https://badge.fury.io/js/question-cache.svg)](http://badge.fury.io/js/question-cache)

> A tiny wrapper around inquirer that makes it easy to create and selectively reuse questions. Useful for project generators like yeoman or generate.

## Install

Install with [npm](https://www.npmjs.com/)

```sh
$ npm i question-cache --save
```

## Usage

```js
var Questions = require('question-cache');

// you must pass your own instance of inquirer!
var questions = new Questions({
  inquirer: require('inquirer')
});
```

## API

### [Questions](index.js#L23)

Create an instance of `Questions` with the given `options`.

**Params**

* `options` **{Object}**: Pass your instance of [inquirer](undefined)on the `inquirer` option.

**Example**

```js
var inquirer = require('inquirer')
var questions = new Questions({inquirer: inquirer});
```

### [.set](index.js#L47)

Store a question object by `key`.

**Params**

* `key` **{String}**: Unique question id.
* `value` **{Object}**: Question object that follows [inquirer](undefined)conventions.

**Example**

```js
questions.set('name', {
  type: 'input',
  message: 'Project name?',
  default: 'undefined'
});
```

### [.get](index.js#L67)

Get a question by `key`.

**Params**

* `key` **{String}**: Unique question id.
* `value` **{Object}**: Question object that follows [inquirer](undefined)conventions.

**Example**

```js
questions.get('name');
//=> {type: 'input', message: 'What is your name?', default: ''}
```

### [.ask](index.js#L84)

Ask a question or array of questions.

**Params**

* `key` **{String}**: Unique question id.
* `value` **{Object}**: Question object that follows [inquirer](undefined)conventions.

**Example**

```js
questions.ask(['name', 'homepage']);
//=> { name: 'foo', homepage: 'https://github/foo' }
```

### [.prompt](index.js#L125)

Exposes the `prompt` method on [inquirer](undefined)as a convenience.

**Params**

* `question` **{Object|Array}**: Question object or array of question objects.
* `callback` **{Object}**: Callback function.

**Example**

```js
questions.prompt({
  type: 'list',
  name: 'chocolate',
  message: 'What\'s your favorite chocolate?',
  choices: ['Mars', 'Oh Henry', 'Hershey']
}, function(answers) {
  //=> {chocolate: 'Hershey'}
});
```

## Example

```js
var Questions = require('question-cache');
var inquirer = require('inquirer');
var questions = new Questions({inquirer: inquirer});

questions
  .set('first', {
    type: 'input',
    message: 'What is your first name?',
    default: ''
  })
  .set('last', {
    type: 'input',
    message: 'What is your last name?',
    default: ''
  })
  .ask(function (err, answers) {
    console.log(answers);
    //=> { first: 'Jon', last: 'Schlinkert' }
  });

/**
 * Nested questions
 */

questions.prompt({
  type: 'list',
  name: 'chocolate',
  message: 'What\'s your favorite chocolate?',
  choices: ['Mars', 'Oh Henry', 'Hershey']
}, function (answers) {
  questions.prompt({
    type: 'list',
    name: 'beverage',
    message: 'And your favorite beverage?',
    choices: ['Pepsi', 'Coke', '7up', 'Mountain Dew', 'Red Bull']
  }, function (answers) {
    console.log(answers);
  });
});
```

**Screen capture**

<img width="669" alt="screen shot 2015-07-13 at 8 05 20 am" src="https://cloud.githubusercontent.com/assets/383994/8649221/00ecc908-2936-11e5-88d2-b1ab75a53ba0.png">

## Other awesome projects

* [generate](https://github.com/generate/generate): Project generator, for node.js.
* [option-cache](https://github.com/jonschlinkert/option-cache): Simple API for managing options in JavaScript applications.
* [verb](https://github.com/assemble/verb): Documentation generator for GitHub projects. Extremely powerful, easy to use, can generate anything from API… [more](https://github.com/assemble/verb)

## Contributing

Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](https://github.com/jonschlinkert/question-cache/issues/new)

## Author

**Jon Schlinkert**

+ [github/jonschlinkert](https://github.com/jonschlinkert)
+ [twitter/jonschlinkert](http://twitter.com/jonschlinkert)

## License

Copyright © 2015 Jon Schlinkert
Released under the MIT license.

***

_This file was generated by [verb-cli](https://github.com/assemble/verb-cli) on July 13, 2015._